==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Prentvnni sa");
define("_FRIEND","Senda essa frtt til vinar");
define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ARTICLES","greinar");
define("_SUBMITNEWS","Senda inn frtt");
define("_SUBMITADVICE","Skrifau frttina/greinina na  eftirfarandi form og lestu hana vel yfir.<br>Athugau a a fara ekki allar frttir  vefinn.<br>Frttin verur lesin yfir og mgulega ltillega breytt af ritstjrum vefsins.");
define("_SUBTITLE","Titill");
define("_BEDESCRIPTIVE","Hafu textann lsandi og einfaldann");
define("_BADTITLES","slmir titlar='Kki  etta!' ea 'Frtt!'");
define("_HTMLISFINE","a er  lagi a nota HTML en athugi a hafa slir og HTML ka rttan!");
define("_AREYOUSURE","Ertu viss um a  hafir haft vefsl me? Athugairu hvort hn s ekki rugglega rtt?");
define("_SUBPREVIEW"," verur a lesa yfir ur en  sendir inn");
define("_SELECTTOPIC","Veldu efnisflokk");
define("_NEWSUBPREVIEW","Yfirlestur  frtt");
define("_STORYLOOK","Frttin n mun lta nokkurnvegin svona t:");
define("_CHECKSTORY","Lestu yfir textann og athugau tengla og esshttar ur en  sendir inn!");
define("_THANKSSUB","Takk fyrir a senda inn!");
define("_SUBSENT","Frttin n hefur veri mttekin...");
define("_SUBTEXT","Vi munum lesa etta yfir  nstum tmum og ef  vi setja  vefinn.");
define("_WEHAVESUB"," augnablikinu ba");
define("_WAITING","greinar eftir yfirlestri.");
define("_PREVIEW","Lesa yfir");
define("_NEWUSER","Nr notandi");
define("_USCORE","Stig");
define("_DATE","Dags");
define("_STORYTEXT","Texti frttar");
define("_EXTENDEDTEXT","Aukatexti");
define("_LANGUAGE","Language");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Prentvnni sa");
define("_FRIEND","Senda essa frtt til vinar");
define("_YOURNAME","Nafn itt");
define("_OK"," lagi!");
define("_ALLOWEDHTML","Leyfilegur HTML ki:");
define("_EXTRANS","breytt (HTML tg yfir  texta)");
define("_HTMLFORMATED","HTML sni");
define("_PLAINTEXT","Venjulegur texti");
define("_ARTICLES","greinar");
define("_SUBMITNEWS","Senda inn frtt");
define("_SUBMITADVICE","Skrifau frttina/greinina na  eftirfarandi form og lestu hana vel yfir.<br>Athugau a a fara ekki allar frttir  vefinn.<br>Frttin verur lesin yfir og mgulega ltillega breytt af ritstjrum vefsins.");
define("_SUBTITLE","Titill");
define("_BEDESCRIPTIVE","Hafu textann lsandi og einfaldann");
define("_BADTITLES","slmir titlar='Kki  etta!' ea 'Frtt!'");
define("_HTMLISFINE","a er  lagi a nota HTML en athugi a hafa slir og HTML ka rttan!");
define("_AREYOUSURE","Ertu viss um a  hafir haft vefsl me? Athugairu hvort hn s ekki rugglega rtt?");
define("_SUBPREVIEW"," verur a lesa yfir ur en  sendir inn");
define("_SELECTTOPIC","Veldu efnisflokk");
define("_NEWSUBPREVIEW","Yfirlestur  frtt");
define("_STORYLOOK","Frttin n mun lta nokkurnvegin svona t:");
define("_CHECKSTORY","Lestu yfir textann og athugau tengla og esshttar ur en  sendir inn!");
define("_THANKSSUB","Takk fyrir a senda inn!");
define("_SUBSENT","Frttin n hefur veri mttekin...");
define("_SUBTEXT","Vi munum lesa etta yfir  nstum tmum og ef  vi setja  vefinn.");
define("_WEHAVESUB"," augnablikinu ba");
define("_WAITING","greinar eftir yfirlestri.");
define("_PREVIEW","Lesa yfir");
define("_NEWUSER","Nr notandi");
define("_USCORE","Stig");
define("_DATE","Dags");
define("_STORYTEXT","Texti frttar");
define("_EXTENDEDTEXT","Aukatexti");
define("_LANGUAGE","Language");

define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
